xrayutilities.materials package
===============================

Submodules
----------

xrayutilities.materials.atom module
-----------------------------------

.. automodule:: xrayutilities.materials.atom
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.cif module
----------------------------------

.. automodule:: xrayutilities.materials.cif
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.database module
---------------------------------------

.. automodule:: xrayutilities.materials.database
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.elements module
---------------------------------------

.. automodule:: xrayutilities.materials.elements
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.heuslerlib module
-----------------------------------------

.. automodule:: xrayutilities.materials.heuslerlib
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.material module
---------------------------------------

.. automodule:: xrayutilities.materials.material
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.plot module
-----------------------------------

.. automodule:: xrayutilities.materials.plot
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.predefined\_materials module
----------------------------------------------------

.. automodule:: xrayutilities.materials.predefined_materials
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.spacegrouplattice module
------------------------------------------------

.. automodule:: xrayutilities.materials.spacegrouplattice
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.materials.wyckpos module
--------------------------------------

.. automodule:: xrayutilities.materials.wyckpos
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: xrayutilities.materials
    :members:
    :undoc-members:
    :show-inheritance:
